/* Define this to be the name of the package */
#undef PACKAGE

/* Define to the version of the package */
#undef VERSION

/* Define to 'int8_t' if not defined anywhere. */
#undef __s8

/* Define to 'u_int8_t' if not defined anywhere. */
#undef __u8

/* Define to 'int16_t' if not defined anywhere. */
#undef __s16

/* Define to 'u_int16_t' if not defined anywhere. */
#undef __u16

/* Define to 'int32_t' if not defined anywhere. */
#undef __s32

/* Define to 'u_int32_t' if not defined anywhere. */
#undef __u32

/* Define to 'int32_t' if not defined anywhere. */
#undef __s64

/* Define to 'u_int32_t' if not defined anywhere. */
#undef __u64

/* Define to 'unsigned' if <sys/types.h> doesn't define. */
#undef loff_t

#undef ENABLE_NLS

#undef ENABLE_MTRACE

#undef HAVE_CATGETS

#undef HAVE_GETTEXT

#undef HAVE_LC_MESSAGES

#undef HAVE_STPCPY

#undef HAVE_LIBREADLINE

/* Define if you have an up-to-date version of ext2_fs.h */
#undef HAVE_EXT2_FS_H

/* Define if you have a working BLKSSZGET, and you want to use it (rather
 * than assume 512 bytes
 */
#undef USE_BLKSSZGET

